from setuptools import setup

setup(name='bgnd_dist',
      version='1.2',
      description='Binomial and Gaussian distributions',
      packages=['bgnd_dist'],
      author='Betini Akarandut',
      author_email='betiniakarandut@gmail.com',
      zip_safe=False)

